$IsElevated = [bool]([Security.Principal.WindowsPrincipal] `
  [Security.Principal.WindowsIdentity]::GetCurrent()).IsInRole([Security.Principal.WindowsBuiltInRole] "Administrator")
$Choices = '&Yes', '&No'

if (-Not $IsElevated) {
  Write-Host "Not running as Administrator. Performing unprivileged actions."

  # Install Scoop
  Write-Host "`nInstall Scoop"
  $ScoopInstaller = "$env:USERPROFILE/Downloads/ScoopInstaller.ps1"
  Invoke-WebRequest -Uri https://get.scoop.sh -OutFile $ScoopInstaller
  &$ScoopInstaller -ScoopDir "$env:LocalAppData/Scoop" -ScoopGlobalDir "$env:ProgramData/Scoop"

  $Decision = $Host.UI.PromptForChoice('Relaunch as Administrator', 'Proceed?', $Choices, 0)
  if ($Decision -eq 0) {
    $Bootstrap = $MyInvocation.MyCommand.Path
    Start-Process -Verb RunAs powershell.exe "-ExecutionPolicy ByPass -NoProfile -File $Bootstrap"
  }
} else {
  Write-Host "Running as Administrator. Performing privileged actions."

  # Install 1Password
  $Decision = $Host.UI.PromptForChoice('Install 1Password', 'Proceed?', $Choices, 0)
  if ($Decision -eq 0) {
    $1passwordInstaller = "$env:USERPROFILE/Downloads/1PasswordSetup-latest.exe"
    Invoke-WebRequest -Uri "https://downloads.1password.com/win/1PasswordSetup-latest.exe" -OutFile "$1passwordInstaller"
    &$1passwordInstaller
    Remove-Item $1passwordInstaller
  } else {
    echo 'Skipping 1Password'
  }

  # Enable Hyper-V
  $Decision = $Host.UI.PromptForChoice('Enable Hyper-V', 'Proceed?', $Choices, 0)
  if ($Decision -eq 0) {
    Enable-WindowsOptionalFeature -Online -FeatureName Microsoft-Hyper-V -All
  } else {
    echo 'Skipping Hyper-V'
  }

  # Enable Containters
  $Decision = $Host.UI.PromptForChoice('Enable Containers', 'Proceed?', $Choices, 0)
  if ($Decision -eq 0) {
    Enable-WindowsOptionalFeature -Online -FeatureName Containers -All
  } else {
    echo 'Skipping Containers'
  }

  # Install Chocolatey
  Write-Host "`nInstall Chocolatey"
  iex ((New-Object System.Net.WebClient).DownloadString('https://community.chocolatey.org/install.ps1'))

  # Install SSH Server
  $Decision = $Host.UI.PromptForChoice('Install SSH Server', 'Proceed?', $Choices, 0)
  if ($Decision -eq 0) {
    choco install --yes "--package-parameters=/SSHServerFeature" openssh
    Start-Service sshd
    Set-Service -Name sshd -StartupType 'Automatic'
  } else {
    echo 'Skipping SSH Server'
  }

  Write-Host 'Press any key to continue...'
  [System.Console]::ReadKey($true)
}
